==> okteta_0.25.4.orig.tar.xz: okteta-0.25.4/kasten/controllers/view/structures/datatypes/datainformationbase.cpp <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2011 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
#include "datainformationbase.h"
#include "topleveldatainformation.h"

DataInformationBase::DataInformationBase() = default;

DataInformationBase::~DataInformationBase() = default;

bool DataInformationBase::isArray() const
{
    return false;
}

bool DataInformationBase::isDummy() const
{
    return false;
}

bool DataInformationBase::isPrimitive() const
{
    return false;
}

bool DataInformationBase::isEnum() const
{
    return false;
}

bool DataInformationBase::isStruct() const
{
    return false;
}

bool DataInformationBase::isUnion() const
{
    return false;
}

bool DataInformationBase::isBitfield() const
{
    return false;
}

bool DataInformationBase::isString() const
{
    return false;
}

bool DataInformationBase::isPointer() const
{
    return false;
}

bool DataInformationBase::isTaggedUnion() const
{
    return false;
}

bool DataInformationBase::isDataInformationWithChildren() const
{
    return false;
}

bool DataInformationBase::isDataInformationWithDummyChildren() const
{
    return false;
}

TopLevelDataInformation* DataInformationBase::asTopLevel()
{
    // multiple inheritance -> we can't use reinterpret_cast -> we have to include the file
    return isTopLevel() ? static_cast<TopLevelDataInformation*>(this) : nullptr;
}

const TopLevelDataInformation* DataInformationBase::asTopLevel() const
{
    // multiple inheritance -> we can't use reinterpret_cast -> we have to include the file
    return isTopLevel() ? static_cast<const TopLevelDataInformation*>(this) : nullptr;
}

==> okteta-0.26.0.tar.xz: okteta-0.26.0/kasten/controllers/view/structures/datatypes/datainformationbase.cpp <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2011 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
#include "datainformationbase.hpp"
#include "topleveldatainformation.hpp"

DataInformationBase::DataInformationBase() = default;

DataInformationBase::~DataInformationBase() = default;

bool DataInformationBase::isArray() const
{
    return false;
}

bool DataInformationBase::isDummy() const
{
    return false;
}

bool DataInformationBase::isPrimitive() const
{
    return false;
}

bool DataInformationBase::isEnum() const
{
    return false;
}

bool DataInformationBase::isStruct() const
{
    return false;
}

bool DataInformationBase::isUnion() const
{
    return false;
}

bool DataInformationBase::isBitfield() const
{
    return false;
}

bool DataInformationBase::isString() const
{
    return false;
}

bool DataInformationBase::isPointer() const
{
    return false;
}

bool DataInformationBase::isTaggedUnion() const
{
    return false;
}

bool DataInformationBase::isDataInformationWithChildren() const
{
    return false;
}

bool DataInformationBase::isDataInformationWithDummyChildren() const
{
    return false;
}

TopLevelDataInformation* DataInformationBase::asTopLevel()
{
    // multiple inheritance -> we can't use reinterpret_cast -> we have to include the file
    return isTopLevel() ? static_cast<TopLevelDataInformation*>(this) : nullptr;
}

const TopLevelDataInformation* DataInformationBase::asTopLevel() const
{
    // multiple inheritance -> we can't use reinterpret_cast -> we have to include the file
    return isTopLevel() ? static_cast<const TopLevelDataInformation*>(this) : nullptr;
}
